==> nextcloud-19.0.10.tgz: nextcloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "活動",
    "An error occurred while loading activities" : "載入活動時發生錯誤",
    "No activity yet" : "尚無活動",
    "Load more activities" : "載入更多活動",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 來複製",
    "{name} (invisible)" : "{name} （隱藏）",
    "{name} (restricted)" : "{name} （受限）",
    "Home" : "首頁",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更動、分享等動態",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "開啟檔案",
    "Personal activity feed for %s" : "%s 的個人動態摘要",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新。",
    "Settings have been updated." : "設定已更新。",
    "Daily activity summary for %s" : "%s 的每日活動摘要",
    "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
    "All activities" : "所有活動",
    "By others" : "由其他人",
    "By you" : "由您",
    "Activity notification for %s" : "%s 的活動通知",
    "Hello %s" : "%s你好",
    "Hello %s," : "哈囉 %s ，",
    "There was some activity at %s" : "%s 有一些活動",
    "Mail" : "電子郵件",
    "Push" : "推送",
    "This application enables users to view actions related to their files in Nextcloud." : "此應用程式允許使用者能夠在 Nextcloud 中查看與其檔案相關的操作。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
    "Activity feed" : "活動摘要",
    "Notifications" : "通知",
    "Enable notification emails" : "啟用電子郵件通知",
    "Default settings" : "預設設定",
    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電子郵件，才能接收通知。",
    "Send notification emails:" : "透過電子郵件接收通知",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Choose for which activities you want to get an email or push notification." : "選擇哪些活動是您要透過電子郵件或推送所接收的通知。",
    "Choose for which activities you want to get a push notification." : "選擇你要推送哪些活動的通知。",
    "Send daily activity summary in the morning" : "於早上傳送每日活動摘要",
    "Settings" : "設定",
    "Enable RSS feed" : "啟用 RSS 摘要",
    "RSS feed" : "RSS 摘要",
    "No more events to load" : "已載入所有事件",
    "Stream" : "串流",
    "Send activity emails" : "寄送有關活動的郵件",
    "Configure the default activity settings for new users." : "為新使用者設置預設活動設定。",
    "List your own actions in the stream" : "列出屬於您的活動。",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "Send emails:" : "寄送郵件：",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "選擇你希望接受到郵件通知或者在應用程式中顯示的活動。",
    "Choose which activities you want to see in your stream." : "請選擇您想在您串流中看到的活動"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.8p0.tgz: nextcloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "活動",
    "An error occurred while loading activities" : "載入活動時發生錯誤",
    "No activity yet" : "尚無活動",
    "Load more activities" : "載入更多活動",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 來複製",
    "{name} (invisible)" : "{name} （隱藏）",
    "{name} (restricted)" : "{name} （受限）",
    "Home" : "首頁",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更動、分享等動態",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "開啟檔案",
    "Personal activity feed for %s" : "%s 的個人動態摘要",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新。",
    "Settings have been updated." : "設定已更新。",
    "Daily activity summary for " : "每日活動摘要：",
    "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
    "All activities" : "所有活動",
    "By others" : "由其他人",
    "By you" : "由您",
    "Activity notification for %s" : "%s 的活動通知",
    "Hello %s" : "%s你好",
    "Hello %s," : "哈囉 %s ，",
    "There was some activity at %s" : "%s 有一些活動",
    "Mail" : "電子郵件",
    "Push" : "推送",
    "This application enables users to view actions related to their files in Nextcloud." : "此應用程式允許使用者能夠在 Nextcloud 中查看與其檔案相關的操作。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
    "Activity feed" : "活動摘要",
    "Notifications" : "通知",
    "Enable notification emails" : "啟用電子郵件通知",
    "Default settings" : "預設設定",
    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電子郵件，才能接收通知。",
    "Send notification emails:" : "透過電子郵件接收通知",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Choose for which activities you want to get an email or push notification." : "選擇哪些活動是您要透過電子郵件或推送所接收的通知。",
    "Choose for which activities you want to get a push notification." : "選擇你要推送哪些活動的通知。",
    "Send daily activity summary in the morning" : "於早上傳送每日活動摘要",
    "Settings" : "設定",
    "Enable RSS feed" : "啟用 RSS 摘要",
    "RSS feed" : "RSS 摘要",
    "No more events to load" : "已載入所有事件",
    "Stream" : "串流",
    "Send activity emails" : "寄送有關活動的郵件",
    "Configure the default activity settings for new users." : "為新使用者設置預設活動設定。",
    "List your own actions in the stream" : "列出屬於您的活動。",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "Send emails:" : "寄送郵件：",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "選擇你希望接受到郵件通知或者在應用程式中顯示的活動。",
    "Choose which activities you want to see in your stream." : "請選擇您想在您串流中看到的活動"
},
"nplurals=1; plural=0;");
